pub struct CommandBufferUsageFlags { /* private fields */ }Implementations
Sourceimpl CommandBufferUsageFlags
impl CommandBufferUsageFlags
pub const FLAG_BITS_MAX_ENUM: CommandBufferUsageFlags
pub const ONE_TIME_SUBMIT: CommandBufferUsageFlags
pub const RENDER_PASS_CONTINUE: CommandBufferUsageFlags
pub const SIMULTANEOUS_USE: CommandBufferUsageFlags
Sourcepub fn empty() -> CommandBufferUsageFlags
pub fn empty() -> CommandBufferUsageFlags
Returns an empty set of flags.
Sourcepub fn all() -> CommandBufferUsageFlags
pub fn all() -> CommandBufferUsageFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<CommandBufferUsageFlags>
pub fn from_bits(bits: u32) -> Option<CommandBufferUsageFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> CommandBufferUsageFlags
pub fn from_bits_truncate(bits: u32) -> CommandBufferUsageFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: CommandBufferUsageFlags) -> bool
pub fn intersects(&self, other: CommandBufferUsageFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: CommandBufferUsageFlags) -> bool
pub fn contains(&self, other: CommandBufferUsageFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: CommandBufferUsageFlags)
pub fn insert(&mut self, other: CommandBufferUsageFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: CommandBufferUsageFlags)
pub fn remove(&mut self, other: CommandBufferUsageFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: CommandBufferUsageFlags)
pub fn toggle(&mut self, other: CommandBufferUsageFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: CommandBufferUsageFlags, value: bool)
pub fn set(&mut self, other: CommandBufferUsageFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.