pub struct ExternalSemaphoreFeatureFlagsKhr { /* private fields */ }Implementations
Sourceimpl ExternalSemaphoreFeatureFlagsKhr
impl ExternalSemaphoreFeatureFlagsKhr
pub const EXPORTABLE: ExternalSemaphoreFeatureFlagsKhr
pub const IMPORTABLE: ExternalSemaphoreFeatureFlagsKhr
pub const FLAG_BITS_MAX_ENUM_KHR: ExternalSemaphoreFeatureFlagsKhr
Sourcepub fn empty() -> ExternalSemaphoreFeatureFlagsKhr
pub fn empty() -> ExternalSemaphoreFeatureFlagsKhr
Returns an empty set of flags.
Sourcepub fn all() -> ExternalSemaphoreFeatureFlagsKhr
pub fn all() -> ExternalSemaphoreFeatureFlagsKhr
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<ExternalSemaphoreFeatureFlagsKhr>
pub fn from_bits(bits: u32) -> Option<ExternalSemaphoreFeatureFlagsKhr>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ExternalSemaphoreFeatureFlagsKhr
pub fn from_bits_truncate(bits: u32) -> ExternalSemaphoreFeatureFlagsKhr
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ExternalSemaphoreFeatureFlagsKhr) -> bool
pub fn intersects(&self, other: ExternalSemaphoreFeatureFlagsKhr) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: ExternalSemaphoreFeatureFlagsKhr) -> bool
pub fn contains(&self, other: ExternalSemaphoreFeatureFlagsKhr) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ExternalSemaphoreFeatureFlagsKhr)
pub fn insert(&mut self, other: ExternalSemaphoreFeatureFlagsKhr)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ExternalSemaphoreFeatureFlagsKhr)
pub fn remove(&mut self, other: ExternalSemaphoreFeatureFlagsKhr)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ExternalSemaphoreFeatureFlagsKhr)
pub fn toggle(&mut self, other: ExternalSemaphoreFeatureFlagsKhr)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: ExternalSemaphoreFeatureFlagsKhr, value: bool)
pub fn set(&mut self, other: ExternalSemaphoreFeatureFlagsKhr, value: bool)
Inserts or removes the specified flags depending on the passed value.