pub struct FenceCreateFlags { /* private fields */ }Implementations
Sourceimpl FenceCreateFlags
impl FenceCreateFlags
pub const FLAG_BITS_MAX_ENUM: FenceCreateFlags
pub const SIGNALED: FenceCreateFlags
Sourcepub fn empty() -> FenceCreateFlags
pub fn empty() -> FenceCreateFlags
Returns an empty set of flags.
Sourcepub fn all() -> FenceCreateFlags
pub fn all() -> FenceCreateFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<FenceCreateFlags>
pub fn from_bits(bits: u32) -> Option<FenceCreateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> FenceCreateFlags
pub fn from_bits_truncate(bits: u32) -> FenceCreateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: FenceCreateFlags) -> bool
pub fn intersects(&self, other: FenceCreateFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: FenceCreateFlags) -> bool
pub fn contains(&self, other: FenceCreateFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: FenceCreateFlags)
pub fn insert(&mut self, other: FenceCreateFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: FenceCreateFlags)
pub fn remove(&mut self, other: FenceCreateFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: FenceCreateFlags)
pub fn toggle(&mut self, other: FenceCreateFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: FenceCreateFlags, value: bool)
pub fn set(&mut self, other: FenceCreateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.