pub struct ImageUsageFlags { /* private fields */ }Implementations
Sourceimpl ImageUsageFlags
impl ImageUsageFlags
pub const FLAG_BITS_MAX_ENUM: ImageUsageFlags
pub const TRANSFER_SRC: ImageUsageFlags
pub const TRANSFER_DST: ImageUsageFlags
pub const SAMPLED: ImageUsageFlags
pub const STORAGE: ImageUsageFlags
pub const COLOR_ATTACHMENT: ImageUsageFlags
pub const DEPTH_STENCIL_ATTACHMENT: ImageUsageFlags
pub const TRANSIENT_ATTACHMENT: ImageUsageFlags
pub const INPUT_ATTACHMENT: ImageUsageFlags
Sourcepub fn empty() -> ImageUsageFlags
pub fn empty() -> ImageUsageFlags
Returns an empty set of flags.
Sourcepub fn all() -> ImageUsageFlags
pub fn all() -> ImageUsageFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<ImageUsageFlags>
pub fn from_bits(bits: u32) -> Option<ImageUsageFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ImageUsageFlags
pub fn from_bits_truncate(bits: u32) -> ImageUsageFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ImageUsageFlags) -> bool
pub fn intersects(&self, other: ImageUsageFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: ImageUsageFlags) -> bool
pub fn contains(&self, other: ImageUsageFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ImageUsageFlags)
pub fn insert(&mut self, other: ImageUsageFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ImageUsageFlags)
pub fn remove(&mut self, other: ImageUsageFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ImageUsageFlags)
pub fn toggle(&mut self, other: ImageUsageFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: ImageUsageFlags, value: bool)
pub fn set(&mut self, other: ImageUsageFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.